# Changelog

## 0.9.0 (2025-04-10)

Full Changelog: [v0.8.2...v0.9.0](https://github.com/hyperspell/python-sdk/compare/v0.8.2...v0.9.0)

### Features

* **api:** api update ([cd17269](https://github.com/hyperspell/python-sdk/commit/cd17269808efe9af49416acb84ae6e1eaa4ef1c4))
* **api:** api update ([#77](https://github.com/hyperspell/python-sdk/issues/77)) ([5df0fc9](https://github.com/hyperspell/python-sdk/commit/5df0fc974b9990b3f00aec8e41822d418f0410ed))
* **api:** api update ([#79](https://github.com/hyperspell/python-sdk/issues/79)) ([4bbaa8b](https://github.com/hyperspell/python-sdk/commit/4bbaa8b5ee05ad8794f838cbba09244639598f1f))
* **api:** api update ([#81](https://github.com/hyperspell/python-sdk/issues/81)) ([816ced9](https://github.com/hyperspell/python-sdk/commit/816ced9a28f9f7d29488c54916f5166c53905a7b))
* **api:** api update ([#82](https://github.com/hyperspell/python-sdk/issues/82)) ([2a12261](https://github.com/hyperspell/python-sdk/commit/2a12261f52ef6c38863f54c46007b31cb888b45e))
* **api:** api update ([#83](https://github.com/hyperspell/python-sdk/issues/83)) ([e349d69](https://github.com/hyperspell/python-sdk/commit/e349d6919cf8bc3276b5da7e8aa3cfa8d4e23a67))
* **api:** api update ([#86](https://github.com/hyperspell/python-sdk/issues/86)) ([9cfa06b](https://github.com/hyperspell/python-sdk/commit/9cfa06b7c4bfab15f9b2e973b767dc02c9961877))


### Chores

* **internal:** expand CI branch coverage ([f1427b7](https://github.com/hyperspell/python-sdk/commit/f1427b73328af89415877c97b15d65ba86fa8ca4))
* **internal:** reduce CI branch coverage ([31cead5](https://github.com/hyperspell/python-sdk/commit/31cead5ba3df9609967a8f8f3f579b4c856fe649))
* **internal:** remove trailing character ([#80](https://github.com/hyperspell/python-sdk/issues/80)) ([f28f2b7](https://github.com/hyperspell/python-sdk/commit/f28f2b705e253c8cb73b67eab20ed9e5c52a8f5d))
* **internal:** slight transform perf improvement ([#84](https://github.com/hyperspell/python-sdk/issues/84)) ([1a6703c](https://github.com/hyperspell/python-sdk/commit/1a6703c8d4f3fe6dd8fc2111c2e3cfd0ade27377))
* slight wording improvement in README ([#85](https://github.com/hyperspell/python-sdk/issues/85)) ([4597f85](https://github.com/hyperspell/python-sdk/commit/4597f85a79b9c4f8b3f1f05744c163aa0c837b73))

## 0.8.2 (2025-03-26)

Full Changelog: [v0.8.1...v0.8.2](https://github.com/hyperspell/python-sdk/compare/v0.8.1...v0.8.2)

### Chores

* update SDK settings ([#74](https://github.com/hyperspell/python-sdk/issues/74)) ([2097566](https://github.com/hyperspell/python-sdk/commit/2097566f6ebaa15a5ab11191d3131f79aa2ae0fb))

## 0.8.1 (2025-03-25)

Full Changelog: [v0.5.3...v0.8.1](https://github.com/hyperspell/python-sdk/compare/v0.5.3...v0.8.1)

### Features

* **api:** api update ([78195d4](https://github.com/hyperspell/python-sdk/commit/78195d43929013ad14e6a079b2c63c2f90fb8377))
* **api:** api update ([#43](https://github.com/hyperspell/python-sdk/issues/43)) ([7c8ccc6](https://github.com/hyperspell/python-sdk/commit/7c8ccc641b0f75f99dbd7a2992c15e03a39143c9))
* **api:** api update ([#44](https://github.com/hyperspell/python-sdk/issues/44)) ([693304c](https://github.com/hyperspell/python-sdk/commit/693304cef80f58fbda0eb78368a2047830f77c50))
* **api:** api update ([#48](https://github.com/hyperspell/python-sdk/issues/48)) ([5a8674d](https://github.com/hyperspell/python-sdk/commit/5a8674d60ac79e1a0e2784bd63aafa2a59727357))
* **api:** api update ([#49](https://github.com/hyperspell/python-sdk/issues/49)) ([2c1476c](https://github.com/hyperspell/python-sdk/commit/2c1476cdb81b093fa1729b830822be93f3709527))
* **api:** api update ([#71](https://github.com/hyperspell/python-sdk/issues/71)) ([5e4a65e](https://github.com/hyperspell/python-sdk/commit/5e4a65e73caf6914b2aa6a847709fb6b490af0f1))
* **api:** update via SDK Studio ([#41](https://github.com/hyperspell/python-sdk/issues/41)) ([2aaad04](https://github.com/hyperspell/python-sdk/commit/2aaad04fee563cf795dd0dbbc9d15b2ee0bbac65))
* **api:** update via SDK Studio ([#67](https://github.com/hyperspell/python-sdk/issues/67)) ([52566fe](https://github.com/hyperspell/python-sdk/commit/52566fe8f84f526eb78a5949b68de52bf0414cd4))
* **api:** update via SDK Studio ([#68](https://github.com/hyperspell/python-sdk/issues/68)) ([3014583](https://github.com/hyperspell/python-sdk/commit/3014583dd53a24950206dc0b2ef7fb3be53fbf55))
* **api:** update via SDK Studio ([#69](https://github.com/hyperspell/python-sdk/issues/69)) ([01cdba5](https://github.com/hyperspell/python-sdk/commit/01cdba5e514ddefc6f0aba9bcff2c8954a3b10e5))
* **api:** update via SDK Studio ([#70](https://github.com/hyperspell/python-sdk/issues/70)) ([f5871a8](https://github.com/hyperspell/python-sdk/commit/f5871a8f77a3839d90ce67bedcf9336caafb227b))
* **api:** update via SDK Studio ([#72](https://github.com/hyperspell/python-sdk/issues/72)) ([3551d71](https://github.com/hyperspell/python-sdk/commit/3551d711e30daaeac10f0935194ba97a30eecf87))
* **client:** allow passing `NotGiven` for body ([#53](https://github.com/hyperspell/python-sdk/issues/53)) ([25f5f65](https://github.com/hyperspell/python-sdk/commit/25f5f65fe53fc426f3901ff5c0dabf77be7b0bdc))
* **client:** send `X-Stainless-Read-Timeout` header ([#45](https://github.com/hyperspell/python-sdk/issues/45)) ([314ac6f](https://github.com/hyperspell/python-sdk/commit/314ac6fbf8b7dbd4b3eb9d5293c4bdf6d21b4f36))


### Bug Fixes

* asyncify on non-asyncio runtimes ([#51](https://github.com/hyperspell/python-sdk/issues/51)) ([9a1d74d](https://github.com/hyperspell/python-sdk/commit/9a1d74da8a683ac1ae3474d298df21e097581a8d))
* **ci:** ensure pip is always available ([#65](https://github.com/hyperspell/python-sdk/issues/65)) ([fc830b0](https://github.com/hyperspell/python-sdk/commit/fc830b067dfc5e4408c772ac2275ad34aa503f97))
* **ci:** remove publishing patch ([#66](https://github.com/hyperspell/python-sdk/issues/66)) ([ca14208](https://github.com/hyperspell/python-sdk/commit/ca142083e62f5214f3b6fdd21a32c233a6d10ced))
* **client:** mark some request bodies as optional ([25f5f65](https://github.com/hyperspell/python-sdk/commit/25f5f65fe53fc426f3901ff5c0dabf77be7b0bdc))
* **types:** handle more discriminated union shapes ([#64](https://github.com/hyperspell/python-sdk/issues/64)) ([ea3ea28](https://github.com/hyperspell/python-sdk/commit/ea3ea28c4fca79d43f3372824dffdf5603d51f27))


### Chores

* **docs:** update client docstring ([#57](https://github.com/hyperspell/python-sdk/issues/57)) ([b93eac9](https://github.com/hyperspell/python-sdk/commit/b93eac92c1aa75241baaeba8979ec9603a538193))
* **internal:** bump rye to 0.44.0 ([#63](https://github.com/hyperspell/python-sdk/issues/63)) ([d0d34fc](https://github.com/hyperspell/python-sdk/commit/d0d34fc3b73469284cdc43bc61bbee53906acb1d))
* **internal:** codegen related update ([#52](https://github.com/hyperspell/python-sdk/issues/52)) ([1663641](https://github.com/hyperspell/python-sdk/commit/166364110507a27382de3ed086da802448a40420))
* **internal:** codegen related update ([#62](https://github.com/hyperspell/python-sdk/issues/62)) ([7d8fa4f](https://github.com/hyperspell/python-sdk/commit/7d8fa4f7989e99c2da10e7119d1f0410d38362db))
* **internal:** fix devcontainers setup ([#54](https://github.com/hyperspell/python-sdk/issues/54)) ([6b255f1](https://github.com/hyperspell/python-sdk/commit/6b255f161ecc1c9113b829327fe162167bf62b9b))
* **internal:** fix type traversing dictionary params ([#46](https://github.com/hyperspell/python-sdk/issues/46)) ([3b755e0](https://github.com/hyperspell/python-sdk/commit/3b755e0e12f723232830aa9398f61b8d55da5735))
* **internal:** minor type handling changes ([#47](https://github.com/hyperspell/python-sdk/issues/47)) ([de1503e](https://github.com/hyperspell/python-sdk/commit/de1503e4e5feabe6267187654467ced1f171ff57))
* **internal:** properly set __pydantic_private__ ([#55](https://github.com/hyperspell/python-sdk/issues/55)) ([412ccce](https://github.com/hyperspell/python-sdk/commit/412ccce91dc434650d88bc4c41f096c06132f1de))
* **internal:** remove extra empty newlines ([#61](https://github.com/hyperspell/python-sdk/issues/61)) ([b299f2e](https://github.com/hyperspell/python-sdk/commit/b299f2e25d537d7baf139579d11826e8fdbf655d))
* **internal:** remove unused http client options forwarding ([#58](https://github.com/hyperspell/python-sdk/issues/58)) ([da92b87](https://github.com/hyperspell/python-sdk/commit/da92b87db946431698648460c2fa71ffaffe3437))
* **internal:** update client tests ([#50](https://github.com/hyperspell/python-sdk/issues/50)) ([f31aeaf](https://github.com/hyperspell/python-sdk/commit/f31aeaf9eaecb541fbc092b5997518efbc8a34e9))


### Documentation

* revise readme docs about nested params ([#59](https://github.com/hyperspell/python-sdk/issues/59)) ([26a8c1e](https://github.com/hyperspell/python-sdk/commit/26a8c1e11b1d4286dbc627db63c064dc05e901f3))
* update URLs from stainlessapi.com to stainless.com ([#56](https://github.com/hyperspell/python-sdk/issues/56)) ([fb40ed8](https://github.com/hyperspell/python-sdk/commit/fb40ed87bdd21583e133307eb6c158d55e49b432))

## 0.5.3 (2025-02-04)

Full Changelog: [v1.0.0...v0.5.3](https://github.com/hyperspell/python-sdk/compare/v1.0.0...v0.5.3)

### Features

* **api:** api update ([#38](https://github.com/hyperspell/python-sdk/issues/38)) ([fd5a6d5](https://github.com/hyperspell/python-sdk/commit/fd5a6d5ba2b090d5cea1e70bf73d1674209c5907))
* **api:** api update ([#39](https://github.com/hyperspell/python-sdk/issues/39)) ([5aaf7cd](https://github.com/hyperspell/python-sdk/commit/5aaf7cd7208f1fef5edfeab8324ad6e977fae517))


### Chores

* **internal:** bummp ruff dependency ([#37](https://github.com/hyperspell/python-sdk/issues/37)) ([cef604a](https://github.com/hyperspell/python-sdk/commit/cef604afecf30df7c584bb70ce4fa61ace9d4742))
* **internal:** change default timeout to an int ([#35](https://github.com/hyperspell/python-sdk/issues/35)) ([f192b6f](https://github.com/hyperspell/python-sdk/commit/f192b6fdf340bfeb9e1853c752df0244841ab8c9))

## 1.0.0 (2025-02-04)

Full Changelog: [v0.1.0-alpha.1...v1.0.0](https://github.com/hyperspell/python-sdk/compare/v0.1.0-alpha.1...v1.0.0)

### Features

* **api:** api update ([#23](https://github.com/hyperspell/python-sdk/issues/23)) ([83dcd1d](https://github.com/hyperspell/python-sdk/commit/83dcd1d6bdd291e299330d532e974ab4e534c06d))
* **api:** api update ([#25](https://github.com/hyperspell/python-sdk/issues/25)) ([26170a5](https://github.com/hyperspell/python-sdk/commit/26170a5f86b9ed0dcbdd6cc01708a3a1a8a161b7))
* **api:** api update ([#28](https://github.com/hyperspell/python-sdk/issues/28)) ([72667ce](https://github.com/hyperspell/python-sdk/commit/72667cec5a0c172460551b0cce48aa667e88b99a))
* **api:** api update ([#29](https://github.com/hyperspell/python-sdk/issues/29)) ([e2312ba](https://github.com/hyperspell/python-sdk/commit/e2312bac25802f12f99f762d1e8e0cd7693dcf23))
* **api:** api update ([#30](https://github.com/hyperspell/python-sdk/issues/30)) ([08bae2f](https://github.com/hyperspell/python-sdk/commit/08bae2f240c913ffae8a6594877f4c78789f20f0))
* **api:** api update ([#31](https://github.com/hyperspell/python-sdk/issues/31)) ([a245e70](https://github.com/hyperspell/python-sdk/commit/a245e70aea6c76a5bdf45685ccb02edf271ab25b))
* **api:** update via SDK Studio ([#32](https://github.com/hyperspell/python-sdk/issues/32)) ([f8f7ad1](https://github.com/hyperspell/python-sdk/commit/f8f7ad136e37e084d5f3b8379d8e58bb04b85f2b))
* **api:** update via SDK Studio ([#33](https://github.com/hyperspell/python-sdk/issues/33)) ([d8aad38](https://github.com/hyperspell/python-sdk/commit/d8aad387e9a44b98f8fb1e2a0564e400203649d7))


### Chores

* **internal:** codegen related update ([#26](https://github.com/hyperspell/python-sdk/issues/26)) ([f6008b9](https://github.com/hyperspell/python-sdk/commit/f6008b93caaecd5b28e50c84dc908d820a0f222b))
* **internal:** minor formatting changes ([#27](https://github.com/hyperspell/python-sdk/issues/27)) ([b58a9f0](https://github.com/hyperspell/python-sdk/commit/b58a9f01edc5f9918f7a29fa81f1a8a1ae93bdfa))

## 0.1.0-alpha.1 (2025-01-21)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/hyperspell/python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([#12](https://github.com/hyperspell/python-sdk/issues/12)) ([14c9569](https://github.com/hyperspell/python-sdk/commit/14c95692111450a03e18b65b9fe84b76b1439741))
* **api:** api update ([#16](https://github.com/hyperspell/python-sdk/issues/16)) ([90ab745](https://github.com/hyperspell/python-sdk/commit/90ab745ece042d2a54a55fec5167db3bfa007618))
* **api:** api update ([#21](https://github.com/hyperspell/python-sdk/issues/21)) ([1b33d5e](https://github.com/hyperspell/python-sdk/commit/1b33d5e6cad083d1f6bfea037ddf79aeb558875b))
* **api:** api update ([#4](https://github.com/hyperspell/python-sdk/issues/4)) ([b44636b](https://github.com/hyperspell/python-sdk/commit/b44636b513256d732590494a99dc0eb1b688df13))
* **api:** api update ([#5](https://github.com/hyperspell/python-sdk/issues/5)) ([3fc9775](https://github.com/hyperspell/python-sdk/commit/3fc97752048e4259b2f0a71358231315fb11cf23))
* **api:** api update ([#7](https://github.com/hyperspell/python-sdk/issues/7)) ([4c43cb7](https://github.com/hyperspell/python-sdk/commit/4c43cb7d7dc11fbe157b9ebb513d753b7210eef4))
* **api:** api update ([#8](https://github.com/hyperspell/python-sdk/issues/8)) ([bbe535f](https://github.com/hyperspell/python-sdk/commit/bbe535f81cefa788f07e6298345bbc1b18b07684))


### Bug Fixes

* **client:** only call .close() when needed ([#11](https://github.com/hyperspell/python-sdk/issues/11)) ([23d4683](https://github.com/hyperspell/python-sdk/commit/23d468363e7b6aa433165ca42491a0351aad4274))
* correctly handle deserialising `cls` fields ([#15](https://github.com/hyperspell/python-sdk/issues/15)) ([dff71c6](https://github.com/hyperspell/python-sdk/commit/dff71c6d918c24b7dcfa0bea38ac7bbdb510b1af))
* **tests:** make test_get_platform less flaky ([#19](https://github.com/hyperspell/python-sdk/issues/19)) ([4886fcf](https://github.com/hyperspell/python-sdk/commit/4886fcf1b23834c6b009c888d68ce8a6b292a79e))


### Chores

* add missing isclass check ([#9](https://github.com/hyperspell/python-sdk/issues/9)) ([12f5ed5](https://github.com/hyperspell/python-sdk/commit/12f5ed56926e50d94b2462636ff8302c29fbf296))
* go live ([#1](https://github.com/hyperspell/python-sdk/issues/1)) ([84713c4](https://github.com/hyperspell/python-sdk/commit/84713c43b10cce946f27e116b7a621c3348a83be))
* **internal:** avoid pytest-asyncio deprecation warning ([#20](https://github.com/hyperspell/python-sdk/issues/20)) ([65f793b](https://github.com/hyperspell/python-sdk/commit/65f793b8d9da0222494949ea590e59123825d57e))
* **internal:** bump httpx dependency ([#10](https://github.com/hyperspell/python-sdk/issues/10)) ([988e555](https://github.com/hyperspell/python-sdk/commit/988e555345b3b193784e7b156d73d3d77eb7d715))
* **internal:** codegen related update ([#14](https://github.com/hyperspell/python-sdk/issues/14)) ([c7e587f](https://github.com/hyperspell/python-sdk/commit/c7e587fc23d72325d491a816a68a55e01d98735b))
* **internal:** codegen related update ([#17](https://github.com/hyperspell/python-sdk/issues/17)) ([9f186e4](https://github.com/hyperspell/python-sdk/commit/9f186e44b8f1c40853cc6f932995379bf187d2a9))
* **internal:** codegen related update ([#6](https://github.com/hyperspell/python-sdk/issues/6)) ([fa47f9e](https://github.com/hyperspell/python-sdk/commit/fa47f9eb5a5677f1a88d5b3034ec900a382f3e45))
* update SDK settings ([#3](https://github.com/hyperspell/python-sdk/issues/3)) ([7d1e0bb](https://github.com/hyperspell/python-sdk/commit/7d1e0bb9ed0d49e2831255d3be1aa3a56503d77a))


### Documentation

* fix typos ([#13](https://github.com/hyperspell/python-sdk/issues/13)) ([84bf7b5](https://github.com/hyperspell/python-sdk/commit/84bf7b55e593e35b5b68ebac64909f21d3431938))
* **raw responses:** fix duplicate `the` ([#18](https://github.com/hyperspell/python-sdk/issues/18)) ([f99b1ca](https://github.com/hyperspell/python-sdk/commit/f99b1cadaa53c54cb27082d401fe376e0ce2f618))
